pub trait CookiesConnExt {
// Required methods
fn with_cookie<'a>(self, cookie: impl Into<Cookie<'a>>) -> Self;
fn cookies(&self) -> &CookieJar;
fn cookies_mut(&mut self) -> &mut CookieJar;
}Expand description
Extension trait adding cookie capacities to Conn.
Important: The CookiesHandler must be
called before any of these functions can be called on a conn.
Required Methods
adds a cookie to the cookie jar and returns the conn
gets a reference to the cookie jar
gets a mutable reference to the cookie jar
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".